@@ -9,7 +9,7 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2009 Ralph Amissah All Rights Reserved.
+ * Copyright: (C) 1997 - 2010, Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -91,7 +91,7 @@ module HARVEST_topics
         idx_array=HARVEST_topics::Harvest.new(file_array,filename,idx_array).extract_harvest
       end
       the_idx=HARVEST_topics::Index.new(idx_array,@@the_idx_topics).construct_book_topic_index
-      #HARVEST_topics::Output_index.new(the_idx).screen_print.cycle
+      #HARVEST_topics::Output_index.new('',the_idx).screen_print.cycle if @opt.cmd.inspect =~/[VM]/
       HARVEST_topics::Output_index.new(@opt,the_idx).html_print.html_songsheet
       puts "file://#{@env.path.output_md_harvest}/harvest_topics.html"
       puts "file://#{@env.path.pwd}/harvest_topics.html" if @opt.cmd.inspect =~/-M/
@@ -125,7 +125,9 @@ module HARVEST_topics
         break if @title and @subtitle and @author and @idx_lst
       end
       @fulltitle=@subtitle ? (@title + ' - ' + @subtitle) : @title
-      if @title and @author_format and @idx_list
+      if @title \
+      and @author_format \
+      and @idx_list
         creator=FORMAT::Author.new(@author_format.strip).author_details
         @authors,@authorship=creator[:authors],creator[:authorship]
         file=if filename=~/~[a-z]{2,3}\.ss[mt]$/
@@ -141,10 +143,10 @@ module HARVEST_topics
           idxl=[]
           g.each do |i|
             i.strip!
-            idxl << { :filename => filename, :file => file, :rough_idx => i, :title => @fulltitle, :author => creator, :page => page}
+            idxl << { :filename =>filename,:file =>file,:rough_idx =>i,:title =>@fulltitle,:author =>creator,:page =>page}
           end
           idxl
-        else { :filename => filename, :file => file, :rough_idx => @idx_list, :title => @fulltitle, :author => creator, :page => page }
+        else { :filename =>filename,:file =>file,:rough_idx =>@idx_list,:title =>@fulltitle,:author =>creator,:page =>page}
         end
       else
         p "missing author field: #@filename title: #@title; author: #@author_format; idx: #@idx_list"
@@ -167,7 +169,7 @@ module HARVEST_topics
         s=n.sub(/(.+?)(?:,.+|$)/,'\1').gsub(/\s+/,'_')
         names += %{<a href="harvest_authors.html##{s}">#{n}</a>, }
       end
-      hash <<  { :filename => idx[:filename], :file => idx[:file], :author => names, :title => idx[:title], :page => idx[:page] }
+      hash << { :filename =>idx[:filename],:file =>idx[:file],:author =>names,:title =>idx[:title],:page =>idx[:page]}
     end
     def construct_book_topic_index
       idx_array=@idx_array
