@@ -7,7 +7,7 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2009 Ralph Amissah All Rights Reserved.
+ * Copyright: (C) 1997 - 2010, Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -57,20 +57,20 @@
 
 =end
 module SiSU_simple_xml_model_dom
-  require "#{SiSU_lib}/particulars"
-  include SiSU_Particulars
-  require "#{SiSU_lib}/defaults"
-  include SiSU_Viz
-  require "#{SiSU_lib}/sysenv"
-  include SiSU_Env
-  require "#{SiSU_lib}/dal_doc_str"
-  require "#{SiSU_lib}/shared_xml"
-  require "#{SiSU_lib}/shared_sem"
-  require "#{SiSU_lib}/xml_format"
-  include SiSU_XML_format
-  include SiSU_XML_munge
-  require "#{SiSU_lib}/rexml"
-  include SiSU_Rexml
+  require "#{SiSU_lib}/particulars"                        # particulars.rb
+    include SiSU_Particulars
+  require "#{SiSU_lib}/defaults"                           # defaults.rb
+    include SiSU_Viz
+  require "#{SiSU_lib}/sysenv"                             # sysenv.rb
+    include SiSU_Env
+  require "#{SiSU_lib}/dal_doc_str"                        # dal_doc_str.rb
+  require "#{SiSU_lib}/shared_xml"                         # shared_xml.rb
+    include SiSU_XML_munge
+  require "#{SiSU_lib}/shared_sem"                         # shared_sem.rb
+  require "#{SiSU_lib}/xml_format"                         # xml_format.rb
+    include SiSU_XML_format
+  require "#{SiSU_lib}/rexml"                              # rexml.rb
+    include SiSU_Rexml
   @@alt_id_count,@@tablehead,@@number_of_cols=0,0,0
   @@tablefoot=''
   class Convert
@@ -126,9 +126,9 @@ module SiSU_simple_xml_model_dom
       end
     end
     class Scroll
-      require "#{SiSU_lib}/shared_txt"
-      require "#{SiSU_lib}/css"
-      include SiSU_text_utils
+      require "#{SiSU_lib}/shared_txt"                     # shared_txt.rb
+      require "#{SiSU_lib}/css"                            # css.rb
+        include SiSU_text_utils
       @@xml={ :body=>[],:open=>[],:close=>[],:head=>[] }
       def initialize(data='',particulars='')
         @data,@env,@md=data,particulars.env,particulars.md
